<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Kliknij ikonę zasobnika 
lub naciśnij ponownie skrót, aby zatrzymać nagrywanie</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Nie obracaj ekranu podczas nagrywania</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Nagrywanie</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Zamknij (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Skopiuj do schowka (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Przechwytywanie ekranu</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Zapisywanie nie powiodło się. Zapisz w swoim katalogu domowym.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Zrzut ekranu zakończony</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>wybierz-obszar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignoruj</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Schowek</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Zapisywanie nagrania, proszę czekać...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Z powodu wyłączenia efektów okna podczas nagrywania, zostanie ono zatrzymane</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Pionowy zrzut ekranu</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Przypnij zrzuty ekranu</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otwórz folder</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Zrzut ekranu zakończony i skopiowany do schowka</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Każde zapytanie</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Określone miejsce</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Ustaw ścieżkę zapisu</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Zmień ścieżkę zapisu</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Przypnij zrzuty ekranu</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nagrywanie</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Nagrywanie</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Nagrywanie zakończone</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Zapisano w %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nagrywanie</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Otwórz folder</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Każde zapytanie</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Określone miejsce</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Ustaw ścieżkę zapisu</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Zmień ścieżkę zapisu</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Przechwytywanie ekranu rozpocznie się za %1 sekund</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Nie udało się utworzyć pionowego zrzutu ekranu</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Dotarto do końca obszaru przewijania</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Osiągnięto maksymalną długość</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>dostosować obszar przechwytywania ekranu</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Przewijaj kółkiem myszy lub klikaj, aby zrobić pionowy zrzut ekranu</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Zwolnij tempo przewijania</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Nieprawidłowy obszar, kliknij aby </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Wprowadź tekst tutaj</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Zrzut ekranu</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Wyjdź/Zapisz</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Dostosowanie rozmiaru</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Szybki start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Zrzut okna</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Opóźniony zrzut ekranu</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Pełny zrzut ekranu</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Prostokąt</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Ołówek</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Cofnij</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Zwiększ wysokość</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Zwiększ wysokość w dół</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Zwiększ szerokość w lewo</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Zwiększ szerokość w prawo</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Zmniejsz wysokość w górę</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Zmniejsz wysokość w dół</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Zmniejsz szerokość w lewo</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Zmniejsz szerokość w prawo</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Wyświetl skróty</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Naciśnięcie klawisza</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Rozpocznij nagrywanie</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Rozpocznij/Nagrywanie</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mysz</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Wydobądź tekst</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Pionowy zrzut ekranu</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Przypnij zrzuty ekranu</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Rozpocznij OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Rozpocznij pionowy zrzut ekranu</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Strzałka</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Nagrywanie</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Prostokąt
Przytrzymaj Shift, aby rysować kwadrat</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipsa
Przytrzymaj Shift, aby rysować koło</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pędzel
Przytrzymaj Shift, aby rysować prostą linię</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Dostosuj siłę rozmycia (Przewijaj, aby dostosować)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Dostosuj rozmiar pędzla (Przewijaj, aby dostosować)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Dostosuj rozmiar tekstu (Przewijaj, aby dostosować)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Pokaż naciśnięcie klawisza (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Ukryj naciśnięcie klawisza (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Pokaż naciśnięcie klawisza (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Włącz kamerę (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Wyłącz kamerę (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Zrzut ekranu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Ustawienia (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Dźwięk</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Audio systemowe</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Pokaż kursor</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Pokaż kliknięcie</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Zapisz do</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Pulpit</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Filmy</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linia (L)
Przytrzymaj Shift, aby rysować pionową lub poziomą linię</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Strzałka (X)
Przytrzymaj Shift, aby rysować pionową lub poziomą strzałkę</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Ołówek (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Rozmycie (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Tekst (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Pionowy zrzut ekranu (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Wydobądź tekst (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Przypnij zrzuty ekranu (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Cofnij (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Nagrywanie</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Zmień ścieżkę zapisu</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Efekty obramówki</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Brak</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Cień</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Obramówka</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Urządzenie</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Wydobądź tekst</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Narzędzia geometryczne (R)
Przytrzymaj Shift, aby narysować kwadraty lub koła.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Zapisz lokalnie</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Zapisz w %1</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Określone miejsce</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Zmień ścieżkę zapisu</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Ustaw ścieżkę zapisu</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Zamknij (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Skopiuj do schowka (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation> Dostosuj obszar nagrywania w zakresie %1*%2, aby uzyskać lepszy efekt</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Nagrywanie ekranu nie jest obecnie obsługiwane</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Wyjdź</translation>
    </message>
</context>
</TS>
